mailr5563 - /1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 10, 2008 - 17:20:
Author: bugman
Date: Thu Apr 10 17:10:05 2008
New Revision: 5563

URL: http://svn.gna.org/viewcvs/relax?rev=5563&view=rev
Log:
Bug fix for the fixed arg test of the diffusion_tensor.init() user function.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py?rev=5563&r1=5562&r2=5563&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py Thu Apr 10 
17:10:05 2008
@@ -26,7 +26,7 @@
 # relax module imports.
 from data import Data as relax_data_store
 from prompt.diffusion_tensor import Diffusion_tensor
-from relax_errors import RelaxError, RelaxBinError, RelaxFloatError, 
RelaxIntError, RelaxNoneStrError, RelaxNumTupleError, RelaxStrError
+from relax_errors import RelaxError, RelaxBoolError, RelaxFloatError, 
RelaxIntError, RelaxNoneStrError, RelaxNumTupleError, RelaxStrError
 from test_suite.unit_tests.diffusion_tensor_testing_base import 
Diffusion_tensor_base_class
 
 # Unit test imports.
@@ -168,9 +168,9 @@
 
         # Loop over the data types.
         for data in DATA_TYPES:
-            # Catch the bin arguments, and skip them.
-            if data[0] == 'bin':
+            # Catch the bool arguments, and skip them.
+            if data[0] == 'bool':
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxBinError, self.diffusion_tensor_fns.init, 
params=1e-9, fixed=data[1])
+            self.assertRaises(RelaxBoolError, 
self.diffusion_tensor_fns.init, params=1e-9, fixed=data[1])




Related Messages


Powered by MHonArc, Updated Thu Apr 10 17:40:12 2008